Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichael Rennie2007-01-25 15:55:15 +0000
committerMichael Rennie2007-01-25 15:55:15 +0000
commitc2e66ad7317314064d10282813f3ff2682fe2872 (patch)
treeff239fbbbe2c3a31301c5eedf263734b50dad9a0 /org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java
parentec3c90c691cfafab291246da23a5d063fe508aab (diff)
downloadeclipse.platform.debug-c2e66ad7317314064d10282813f3ff2682fe2872.tar.gz
eclipse.platform.debug-c2e66ad7317314064d10282813f3ff2682fe2872.tar.xz
eclipse.platform.debug-c2e66ad7317314064d10282813f3ff2682fe2872.zip
Bug 74480
[launching] Simplify the launch experience for less technical users of Eclipse
Diffstat (limited to 'org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java')
-rw-r--r--org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java16
1 files changed, 13 insertions, 3 deletions
diff --git a/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java b/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java
index 623c9cefe..29878c97d 100644
--- a/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java
+++ b/org.eclipse.debug.ui/ui/org/eclipse/debug/internal/ui/launchConfigurations/LaunchConfigurationTabGroupViewer.java
@@ -360,7 +360,7 @@ public class LaunchConfigurationTabGroupViewer extends Viewer {
/**
* Creates some help text for the tab group launch types
- * @param parent thep arent composite
+ * @param parent the parent composite
* @since 3.2
*/
private void createGettingStarted(Composite parent) {
@@ -492,7 +492,14 @@ public class LaunchConfigurationTabGroupViewer extends Viewer {
ILaunchConfigurationTab[] tabs = getTabs();
if (tabs != null) {
// update the working copy from the active tab
+ boolean newwc = !getWorkingCopy().isDirty();
getActiveTab().performApply(getWorkingCopy());
+ if(getOriginal() instanceof ILaunchConfigurationWorkingCopy && newwc) {
+ try {
+ getWorkingCopy().doSave();
+ }
+ catch (CoreException e) {DebugUIPlugin.log(e);}
+ }
updateButtons();
// update error ticks
CTabItem item = null;
@@ -948,6 +955,9 @@ public class LaunchConfigurationTabGroupViewer extends Viewer {
if (workingCopy == null) {
return false;
}
+ if(workingCopy.getParent() != null) {
+ return !workingCopy.getParent().contentsEqual(workingCopy);
+ }
// Working copy hasn't been saved
if (workingCopy.getOriginal() == null) {
return true;
@@ -1111,7 +1121,7 @@ public class LaunchConfigurationTabGroupViewer extends Viewer {
/**
* Determines if the currently showing launch configuration has multiple launch delegates for the same mode set, but does not care
* if there has been a default selected yet or not
* @return true if the current launch configuraiton has multiple launch delegates, false otherwise
*/
private boolean hasMultipleDelegates() {
ILaunchConfiguration config = getWorkingCopy();
@@ -1354,8 +1364,8 @@ public class LaunchConfigurationTabGroupViewer extends Viewer {
try {
if(fTabGroup != null) {
fTabGroup.initializeFrom(fOriginal);
- fWorkingCopy = fOriginal.getWorkingCopy();
fNameWidget.setText(fOriginal.getName());
+ fWorkingCopy = fOriginal.getWorkingCopy();
refreshStatus();
}
}
@@ -1111,7 +1121,7 @@ public class LaunchConfigurationTabGroupViewer extends Viewer {
* Determines if the currently showing launch configuration has multiple launch delegates for the same mode set, but does not care
* if there has been a default selected yet or not
- * @return true if the current launch configuraiton has multiple launch delegates, false otherwise
+ * @return true if the current launch configuration has multiple launch delegates, false otherwise
*/
private boolean hasMultipleDelegates() {

Back to the top